# Copyright (C) 2012-2022 jrnl contributors
# License: https://www.gnu.org/licenses/gpl-3.0.html

import sys

from jrnl.cli import cli

if __name__ == "__main__":
    sys.exit(cli())
